import ujson as json
import requests

from .lib.util import objects, exceptions


class Client:
    def __init__(self):
        self.api = "https://dbsl.ga/api"

    def get_server_info(self, guildId: int):
        response = requests.get(f"{self.api}/s/{guildId}")
        if response.status_code != 200: raise exceptions.CheckException(json.loads(response.text))
        else: return objects.Server(json.loads(response.text)["guild"])


class Server:
    def __init__(self, data):
        self.json = data

        try: self.prefix: str = data["prefix"]
        except (KeyError, TypeError): self.prefix: str = "Undefined"
        try: self.name: str = data["name"]
        except (KeyError, TypeError): self.name: str = "Undefined"
        try: self.icon: str = data["icon"]
        except (KeyError, TypeError): self.icon: str = "Undefined"
        try: self.description: str = data["description"]
        except (KeyError, TypeError): self.invite: str = "Undefined"
        try: self.invite: str = data["invite"]
        except (KeyError, TypeError): self.invite: str = "Undefined"

        try: self.isBlacklisted: bool = data["blacklisted"]
        except (KeyError, TypeError): self.isBlacklisted: bool = False
        try: self.isFeatured: bool = data["featured"]
        except (KeyError, TypeError): self.isFeatured: bool = False
        try: self.isVerified: int = data["verified"]
        except (KeyError, TypeError): self.isVerified: int = -1

        try: self.serverId: int = data["id"]
        except (KeyError, TypeError): self.serverId: int = -1
        try: self.mongoId: int = data["_id"]
        except (KeyError, TypeError): self.mongoId: int = -1

        try: self.userCount: int = data["users"]
        except (KeyError, TypeError): self.userCount: int = -1
        # try: self.bumpCount: int = data["bumps"]
        # except (KeyError, TypeError): self.bumpCount: int = -1


class NotFound(Exception):
    def __init__(*args, **kwargs):
        Exception.__init__(*args, **kwargs)

class LibraryUpdateAvailable(Exception):
    def __init__(*args, **kwargs):
        Exception.__init__(*args, **kwargs)


def CheckException(data):
    errorCode: int = data["code"]
    errorMessage: str = data["message"]

    if errorCode == 404: raise NotFound(errorMessage)
    else: raise Exception(errorMessage)


__title__ = 'DBSL.py'
__author__ = 'Team Wezacon'
__license__ = 'MIT'
__copyright__ = 'Copyright 2020-2020 Wezacon'
__version__ = '0.0.5'

from .client import Client
from .lib.util import objects, exceptions
from requests import get
from json import loads

__newest__ = loads(get("https://pypi.python.org/pypi/dbsl.py/json").text)["info"]["version"]

if __version__ != __newest__:
    print(exceptions.LibraryUpdateAvailable(f"New version available for {__title__}: '{__newest__}' (Using: '{__version__}')\nGet latest here: https://pypi.python.org/pypi/dbsl.py\nInstall command: 'pip install DBSL.py=={__newest__}'"))



from setuptools import setup, find_packages

with open("README.md", "r") as stream:
    long_description = stream.read()

setup(
    name = 'DBSL.py',
    version = '0.0.5',
    url = 'https://github.com/wezacon/DBSL.py',
    download_url = 'https://github.com/wezacon/DBSL.py/tarball/master',
    license = 'MIT',
    author = 'Team Wezacon',
    author_email = 'wezacon.com@gmail.com',
    description = 'API wrapper for DBSL',
    long_description = long_description,
    long_description_content_type = 'text/markdown',
    keywords = [
        'DBSL',
        'DBSL-py',
        'wezacon',
        'official'
    ],
    install_requires = [
        'setuptools',
        'requests',
        'six',
        'ujson'
    ],
    setup_requires = [
        'wheel'
    ],
    packages = find_packages()
)
